import { Controller, Get, Inject, Query } from '@midwayjs/core';
import { NeedLoginMiddleware } from '../middleware/needLogin.middleware';
import { ContactSearchService } from '../service/contactSearch.service';

/**
 * 预约对接查询匹配度
 */
@Controller('/cs', { middleware: [NeedLoginMiddleware] })
export class ContactSearchController {
  @Inject()
  csService: ContactSearchService;
  /**
   * 来源是需求的匹配查询
   * 需要查询 当前用户 通过审核的 供给和成果数据
   * @param keyword 关键词
   */
  @Get('/demand')
  async demand(@Query('keyword') keyword: string) {
    if (!keyword) return;
    const supplyConfig = { index: 'supply', fields: ['name', 'tags', 'brief'] };
    const sres = await this.csService.search(keyword, supplyConfig);
    const achievementConfig = { index: 'achievement', fields: ['name', 'tags', 'brief'] };
    const ares = await this.csService.search(keyword, achievementConfig);
    return sres || ares;
  }

  /**
   * 来源是供给的匹配查询
   * 需要查询 当前用户 通过审核的 需求数据
   * @param keyword 关键词
   */
  @Get('/supply')
  async supply(@Query('keyword') keyword: string) {
    const config = { index: 'demand', fields: ['name', 'tags', 'brief'] };
    const res = await this.csService.search(keyword, config);
    return res;
  }

  /**
   * 来源是项目的匹配查询
   * 需要查询 当前用户 通过审核的 需求数据
   * @param keyword 关键词
   */
  @Get('/project')
  async projectr(@Query('keyword') keyword: string) {
    const config = { index: 'demand', fields: ['name', 'tags', 'brief'] };
    const res = await this.csService.search(keyword, config);
    return res;
  }

  /**
   * 来源是成果的匹配查询
   * 需要查询 当前用户 通过审核的 需求数据
   * @param keyword 关键词
   */
  @Get('/achievement')
  async achievement(@Query('keyword') keyword: string) {
    const config = { index: 'demand', fields: ['name', 'tags', 'brief'] };
    const res = await this.csService.search(keyword, config);
    return res;
  }
}
